/*
 * Copyright 2000-2013 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.jetbrains.python.inspections;

import com.jetbrains.python.fixtures.PyTestCase;
import com.jetbrains.python.psi.LanguageLevel;

/**
 * @author yole
 */
public class PyMissingConstructorTest extends PyTestCase {
  private static final String TEST_DIRECTORY = "inspections/PyMissingConstructorInspection/";
  
  public void testBasic() {
    doTest();
  }
  
  public void testQualifiedName() { // PY-3278
    doTest();
  }
  
  public void testNoConstructor() {  // PY-3238
    doTest();
  }
  
  public void testDeepInheritance() {  // PY-3313
    doTest();
  }
  
  public void testInheritFromSelf() {  // PY-3395
    doTest();
  }

  public void testDunderClass() {  // PY-4038
    doTest();
  }

  public void testException() { // PY-7176
    doTest();
  }

  public void testInnerClass() { //PY-7699
    doTest();
  }
  
  public void testPy3k() {
    setLanguageLevel(LanguageLevel.PYTHON30);
    doTest();
  }

  private void doTest() {
    myFixture.configureByFile(TEST_DIRECTORY + getTestName(true) + ".py");
    myFixture.enableInspections(PyMissingConstructorInspection.class);
    myFixture.checkHighlighting(true, false, false);
  }
}
